@@ -24,30 +24,37 @@
 #include <string>
 #include <QString>
 
-class OdsException: public std::exception {
-public:
-  OdsException(QString message) throw () {
+class OdsException : public std::exception
+{
+  public:
+  OdsException(QString message) throw()
+  {
     _message = message;
   }
-  
+
   /*mcqError(std::string message = "") throw () :
     _message(message.c_str()) {
     }*/
-  
-    
-  virtual const char * what() const throw () override {
+
+
+  virtual const char *
+  what() const throw() override
+  {
     return _message.toStdString().c_str();
   }
-  
-  virtual const QString & qwhat() const throw () {
+
+  virtual const QString &
+  qwhat() const throw()
+  {
     return _message;
   }
-  
-  virtual ~OdsException() throw () {
+
+  virtual ~OdsException() throw()
+  {
   }
-  
- private:
-  QString _message; //Description de l'erreur
+
+  private:
+  QString _message; // Description de l'erreur
 };
 
 #endif // ODSEXCEPTION_H
