@@ -19,26 +19,34 @@
 
 #include "tsvoutputstream.h"
 
-TsvOutputStream::TsvOutputStream(QTextStream & otxtstream):TsvDirectoryWriter()
+TsvOutputStream::TsvOutputStream(QTextStream &otxtstream) : TsvDirectoryWriter()
 {
-    _p_otxtstream = &otxtstream;
+  _p_otxtstream = &otxtstream;
 }
 
 TsvOutputStream::~TsvOutputStream()
 {
-    //close();
-    _p_otxtstream = nullptr;
+  // close();
+  _p_otxtstream = nullptr;
 }
 
-void TsvOutputStream::close() {
-    _p_otxtstream->flush();
+void
+TsvOutputStream::close()
+{
+  _p_otxtstream->flush();
 }
 
-void TsvOutputStream::setNoSheetName(bool no_sheet_name) {
+void
+TsvOutputStream::setNoSheetName(bool no_sheet_name)
+{
   _no_sheet_name = no_sheet_name;
 }
 
-void TsvOutputStream::writeSheet(const QString & sheetName) {
-    if (_no_sheet_name) return;
-    *_p_otxtstream << _end_of_line << _end_of_line << "**** " << sheetName << " ****"<< _end_of_line;
+void
+TsvOutputStream::writeSheet(const QString &sheetName)
+{
+  if(_no_sheet_name)
+    return;
+  *_p_otxtstream << _end_of_line << _end_of_line << "**** " << sheetName
+                 << " ****" << _end_of_line;
 }
