@@ -22,23 +22,23 @@
 
 #include "tsvdirectorywriter.h"
 
-class TsvOutputStream: public TsvDirectoryWriter
+class TsvOutputStream : public TsvDirectoryWriter
 {
-public:
-    TsvOutputStream(QTextStream & otxtstream);
-    ~TsvOutputStream();
+  public:
+  TsvOutputStream(QTextStream &otxtstream);
+  virtual ~TsvOutputStream();
 
-    void close() override;
-    virtual void writeSheet(const QString & sheetName) override;
+  void close() override;
+  virtual void writeSheet(const QString &sheetName) override;
 
-    /** @brief toggle writing sheet name in text stream to off
-     * usefull if you only need one sheet
-     * the wrisheet function can also be overloaded in a derived class
-     * */
-    void setNoSheetName(bool no_sheet_name);
-private:
-    bool _no_sheet_name = false;
+  /** @brief toggle writing sheet name in text stream to off
+   * usefull if you only need one sheet
+   * the wrisheet function can also be overloaded in a derived class
+   * */
+  void setNoSheetName(bool no_sheet_name);
 
+  private:
+  bool _no_sheet_name = false;
 };
 
 #endif // TSVOUTPUTSTREAM_H
